@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 2003, 2006 Matteo Frigo
- * Copyright (c) 2003, 2006 Massachusetts Institute of Technology
+ * Copyright (c) 2003, 2007-11 Matteo Frigo
+ * Copyright (c) 2003, 2007-11 Massachusetts Institute of Technology
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,6 @@
  *
  */
 
-/* $Id: verify-lib.c,v 1.19 2006-01-05 03:04:27 stevenj Exp $ */
 
 #include "verify.h"
 #include <math.h>
@@ -229,18 +228,18 @@ double acmp(C *a, C *b, int n, const char *test, double tol)
 {
      double d = aerror(a, b, n);
      if (d > tol) {
-	  fprintf(stderr, "Found relative error %e (%s)\n", d, test);
+	  ovtpvt_err("Found relative error %e (%s)\n", d, test);
 
 	  {
-	       int i;
-	       for (i = 0; i < n; ++i) 
-		    fprintf(stderr,
-			    "%8d %16.12f %16.12f   %16.12f %16.12f\n", i, 
-			   (double) c_re(a[i]), (double) c_im(a[i]),
-			   (double) c_re(b[i]), (double) c_im(b[i]));
+	       int i, N;
+	       N = n > 300 && verbose <= 2 ? 300 : n;
+	       for (i = 0; i < N; ++i) 
+		    ovtpvt_err("%8d %16.12f %16.12f   %16.12f %16.12f\n", i, 
+			       (double) c_re(a[i]), (double) c_im(a[i]),
+			       (double) c_re(b[i]), (double) c_im(b[i]));
 	  }
 
-	  exit(EXIT_FAILURE);
+	  bench_exit(EXIT_FAILURE);
      }
      return d;
 }
@@ -288,13 +287,12 @@ double impulse(dofft_closure *k,
 	       C *outA, C *outB, C *outC,
 	       C *tmp, int rounds, double tol)
 {
-     int N = n * vecn;
      int i, j;
      double e = 0.0;
 
      /* check impulsive input */
      for (i = 0; i < vecn; ++i) {
-	  R x = (i+1) / (double)(vecn+1);
+	  R x = (sqrt(n)*(i+1)) / (double)(vecn+1);
 	  for (j = 0; j < n; ++j) {
 	       c_re(inA[j + i * n]) = 0;
 	       c_im(inA[j + i * n]) = 0;
@@ -310,7 +308,7 @@ double impulse(dofft_closure *k,
 
      /* check constant input */
      for (i = 0; i < vecn; ++i) {
-	  R x = (i+1) / (double)(vecn+1);
+	  R x = (i+1) / ((double)(vecn+1) * sqrt(n));
 	  for (j = 0; j < n; ++j) {
 	       c_re(inA[j + i * n]) = x;
 	       c_im(inA[j + i * n]) = 0;
